@@ -3,10 +3,34 @@ A couple of helper functions to help enabling Widget in ModelForms.
 """
 from django.forms.models import modelform_factory as django_modelform_factory
 from django.db.models import ForeignKey, OneToOneField
+from django.utils.translation import ugettext_lazy as _
+from django import forms
 
 from .widgets import ChoiceWidget, MultipleChoiceWidget
 
-__all__ = ['get_widgets_dict', 'modelform_factory']
+__all__ = ['get_widgets_dict', 'modelform_factory', 'FixedModelForm']
+
+M = _(' Hold down "Control", or "Command" on a Mac, to select more than one.')
+
+
+class FixedModelForm(forms.ModelForm):
+    """
+    Simple child of FixedModelForm that removes the 'Hold down "Control" ...'
+    message that is enforced in select multiple fields. Added in 1.0.23.
+
+    See https://code.djangoproject.com/ticket/9321
+    """
+
+    def __init__(self, *args, **kwargs):
+        super(FixedModelForm, self).__init__(*args, **kwargs)
+
+        msg = unicode(M)
+
+        for name, field in self.fields.items():
+            if not isinstance(field.widget, MultipleChoiceWidget):
+                continue
+
+            field.help_text = field.help_text.replace(msg, '')
 
 
 def get_widgets_dict(model, autocomplete_exclude=None, registry=None):
@@ -85,4 +109,4 @@ def modelform_factory(model, autocomplete_exclude=None, registry=None,
     widgets.update(kwargs.pop('widgets', {}))
     kwargs['widgets'] = widgets
 
-    return django_modelform_factory(model, **kwargs)
+    return django_modelform_factory(model, form=FixedModelForm, **kwargs)
