@@ -5,7 +5,8 @@ and MultipleChoiceWidget for django's SelectMultiple.
 Constructing a widget needs an Autocomplete class or registered autocomplete
 name.
 
-The widget renders from autocomplete_light/widget.html template.
+The choice autocomplete widget renders from autocomplete_light/widget.html
+template.
 """
 
 from django import forms
@@ -29,7 +30,8 @@ class WidgetBase(object):
     """
 
     def __init__(self, autocomplete,
-                 widget_js_attributes=None, autocomplete_js_attributes=None):
+                 widget_js_attributes=None, autocomplete_js_attributes=None,
+                 add_another_url=None):
 
         if isinstance(autocomplete, str):
             self.autocomplete_name = autocomplete
@@ -49,6 +51,8 @@ class WidgetBase(object):
         else:
             self.autocomplete_js_attributes = autocomplete_js_attributes
 
+        self.add_another_url = add_another_url
+
     def process_js_attributes(self):
         extra_autocomplete_js_attributes = getattr(self.autocomplete,
             'autocomplete_js_attributes', {})
